==> apache-druid-28.0.1-src.tar.gz: apache-druid-28.0.1-src/extensions-contrib/druid-iceberg-extensions/src/test/java/org/apache/druid/iceberg/input/LocalCatalogTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.iceberg.input;

import com.fasterxml.jackson.core.JsonProcessingException;
import nl.jqno.equalsverifier.EqualsVerifier;
import org.apache.druid.jackson.DefaultObjectMapper;
import org.apache.druid.java.util.common.FileUtils;
import org.junit.Assert;
import org.junit.Test;

import java.io.File;
import java.util.HashMap;

public class LocalCatalogTest
{
  @Test
  public void testCatalogSerDe() throws JsonProcessingException
  {
    final File warehouseDir = FileUtils.createTempDir();
    DefaultObjectMapper mapper = new DefaultObjectMapper();
    LocalCatalog before = new LocalCatalog(warehouseDir.getPath(), new HashMap<>());
    LocalCatalog after = mapper.readValue(
        mapper.writeValueAsString(before), LocalCatalog.class);
    Assert.assertEquals(before, after);
    Assert.assertEquals("hadoop", before.retrieveCatalog().name());
    Assert.assertEquals("hadoop", after.retrieveCatalog().name());
  }

  @Test
  public void testEqualsContract()
  {
    EqualsVerifier.forClass(LocalCatalog.class).withNonnullFields("warehousePath").withIgnoredFields("catalog").usingGetClass().verify();
  }
}

==> apache-druid-33.0.0-src.tar.gz: apache-druid-33.0.0-src/extensions-contrib/druid-iceberg-extensions/src/test/java/org/apache/druid/iceberg/input/LocalCatalogTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.iceberg.input;

import com.fasterxml.jackson.core.JsonProcessingException;
import nl.jqno.equalsverifier.EqualsVerifier;
import org.apache.druid.jackson.DefaultObjectMapper;
import org.apache.druid.java.util.common.FileUtils;
import org.junit.Assert;
import org.junit.Test;

import java.io.File;
import java.util.HashMap;

public class LocalCatalogTest
{
  @Test
  public void testCatalogSerDe() throws JsonProcessingException
  {
    final File warehouseDir = FileUtils.createTempDir();
    DefaultObjectMapper mapper = new DefaultObjectMapper();
    LocalCatalog before = new LocalCatalog(warehouseDir.getPath(), new HashMap<>(), true);
    LocalCatalog after = mapper.readValue(
        mapper.writeValueAsString(before), LocalCatalog.class);
    Assert.assertEquals(before, after);
    Assert.assertEquals("hadoop", before.retrieveCatalog().name());
    Assert.assertEquals("hadoop", after.retrieveCatalog().name());
  }

  @Test
  public void testEqualsContract()
  {
    EqualsVerifier.forClass(LocalCatalog.class).withNonnullFields("warehousePath").withIgnoredFields("catalog").usingGetClass().verify();
  }
}
